/***************************************************************************
                             graphnode.h
                             -------------------
    begin                : Fri Jun 10 2005
    copyright            : (C) 2005 by Elad Lahav
    email                : elad_lahav@users.sf.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef GRAPHNODE_H
#define GRAPHNODE_H

#include <qcanvas.h>
#include "graphviz.h"

/**
 * A canvas item that draws the name of a function insider a filled rectangle.
 * This item represents a function in the call graph.
 * @author Elad Lahav
 */
class GraphNode : public QCanvasPolygon
{
public:
	GraphNode(QCanvas*, Agnode_t*);
	~GraphNode();
	
	/**
	 * @return	The graph node drawn by this item
	 */
	Agnode_t* getNode() { return m_pNode; }

	/**
	 * @param	font	The font to use for drawing the text
	 */
	void setFont(const QFont& font) { m_font = font; }
	
	/**
	 * @param	sText	The text to draw
	 */
	void setText(const QString& sText) { m_sText = sText; }
	
	/**
	 * @param	ptTextPos	The position of the text
	 */
	void setTextPos(const QPoint& ptTextPos) { m_ptTextPos = ptTextPos;	}
	
	/**
	 * @return	The name of the function
	 */
	const QString& getText() const { return m_sText; }
	
	/** Identifies this class among other QCanvasItem classes. */
	static int RTTI;

	/** @return	The class identifier. */
	virtual int rtti() const { return RTTI; }
	
protected:
	virtual void draw(QPainter&);
	
private:
	/** The graph node drawn by this item. */
	Agnode_t* m_pNode;
	
	/** The name of the function to draw. */
	QString m_sText;

	/** The location of the text to draw. */
	QPoint m_ptTextPos;

	/** The font to use for drawing the text. */
	QFont m_font;
};

#endif
