/***************************************************************************
                             quickdefdlg.h
                             -------------------
    begin                : Tue Jun 14 2005
    copyright            : (C) 2005 by Elad Lahav
    email                : elad_lahav@users.sf.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef QUICKDEFDLG_H
#define QUICKDEFDLG_H

#include <qlistview.h>
#include "quickdeflayout.h"
#include "cscopefrontend.h"

/**
 * Executes a definition query and displays its results in a list view.
 * This dialogue is used to launch a "Quick Definition" query, which does not
 * invoke the symbol dialogue and which bypasses the query widget.
 * The dialogue is initially hidden, and is only shown in one of two cases:
 * 1. Progress information is available
 * 2. The query has resulted in more than one record.
 * If only a single record is returned by Cscope, it is automatically 
 * selected. Otherwise, the user needs to explicitly select a record. In both
 * cases the dialogue is destroyed upon selection of a record.
 * @author	Elad Lahav
 */
class QuickDefDlg : public QuickDefLayout
{
	Q_OBJECT

public:
	QuickDefDlg(QWidget* pParent = 0, const char* szName = 0);
	~QuickDefDlg();
	
	void query(const QString&);
	
signals:
	/**
	 * Emitted when a query record is selected.
	 * @param	sFile	The file to which the record points
	 * @param	nLine	The record's line number
	 */
	void lineRequested(const QString& sFile, uint nLine);
	
protected slots:
	virtual void slotRecordSelected(QListViewItem*);
	
private:
	/** Used to display query progress information. */
	CscopeProgress m_progress;
	
private slots:
	void slotDataReady(FrontendToken*);
	void slotProgress(int, int);
	void slotFinished(uint);
};

#endif

